<?php
/*
Plugin Name: VK.com Iframe
Description: Parse video embeds from vk.com
Version: 1.0
Author: Janis Elsts

ModuleCategory: parser
ModuleClassName: blcVkFrameParser
ModuleContext: on-demand
ModuleLazyInit: true

ModulePriority: 100
*/

class blcVkFrameParser extends blcParser {
	public $supported_formats = array('html');

	function parse($content, $base_url = '', $default_link_text = '') {
		$instances = array();
		$pattern = '#<iframe\s[^>]*?src\s*?=\s*?[\'"](?P<src>[^\'"]+?)[\'"][^>]*?>[\s\n\r]*?</\s*?iframe>#i';

		if ( preg_match_all($pattern, $content, $matches, PREG_SET_ORDER) ) {
			foreach($matches as $match) {
				$url = $match['src'];
				$parts = @parse_url($url);

				//We only care about frames where the SRC is a valid URL that points to vk.com.
				if ( empty($parts) || !isset($parts['host']) || !in_array($parts['host'], array('vk.com', 'www.vk.com')) ) {
					continue;
				}

				//The frame source is usually structured like this:
				//http://vk.com/video_ext.php?oid=88588150&id=164114261&hash=f12eaab3766ee44c&hd=1
				if ( !isset($parts['path']) || strpos($parts['path'], 'video_ext.') === false ) {
					continue;
				}

				//Create a new link instance.
				$instance = new blcLinkInstance();

				$instance->set_parser($this);
				$instance->raw_url = $match[0];
				$instance->link_text = $url;

				$link_obj = new blcLink($url);
				$instance->set_link($link_obj);

				$instances[] = $instance;
			}
		}

		return $instances;
	}

	/**
	 * Editing is disabled in embed parsers.
	 *
	 * @param string $content
	 * @param string $new_url
	 * @param string $old_url
	 * @param string $old_raw_url
	 * @return WP_Error
	 */
	function edit($content, $new_url, $old_url, $old_raw_url){
		return new WP_Error(
			'not_implemented',
			sprintf(__("Embedded videos can't be edited using Broken Link Checker. Please edit or replace the video in question manually.", 'broken-link-checker'), $this->parser_type)
		);
	}

	/**
	 * Remove all occurrences of the specified video from a string.
	 *
	 * @param string $content Look for vk.com videos in this string.
	 * @param string $url Ignored.
	 * @param string $embed_code The full embed code to look for.
	 * @return string Input string with all matching embeds removed.
	 */
	function unlink($content, $url, $embed_code){
		if ( empty($embed_code) ){
			return $content;
		}

		return str_replace($embed_code, '', $content); //Super-simple.
	}
}